@@ -4,7 +4,7 @@ use strict;
 use Class::ISA;
 use Text::SimpleTable;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 our $RAW     = 0;
 
 =head1 NAME
@@ -85,7 +85,7 @@ sub import {
         }
         close IN;
         foreach (@overloads) {
-            $np->row( wrap( $_, 47, 1 ) ) unless $provided{$_};
+            $np->row( $_, 47, 1 ) unless $provided{$_};
             push @np, "$_\n";
             push( @{ $overloaded{$_} }, $super );
         }
